aboutsummaryrefslogtreecommitdiffstats
path: root/lib/public/Search/IProvider.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/Search/IProvider.php')
-rw-r--r--lib/public/Search/IProvider.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/public/Search/IProvider.php b/lib/public/Search/IProvider.php
index 5a6cfb3fd03..a91efa55fe1 100644
--- a/lib/public/Search/IProvider.php
+++ b/lib/public/Search/IProvider.php
@@ -68,13 +68,14 @@ interface IProvider {
* Get the search provider order
* The lower the int, the higher it will be sorted (0 will be before 10)
*
* @param string $from the url the user is currently at. (e.g. /apps/files/?dir=/&fileid=982)
*
* @return int
*
* @since 20.0.0
*/
- public function getOrder(string $from): int;
+ public function getOrder(string $route, array $routeParameters): int;
/**
* Find matching search entries in an app
@@ -68,13 +68,14 @@ interface IProvider {
* The lower the int, the higher it will be sorted (0 will be before 10)
*
- * @param string $from the url the user is currently at. (e.g. /apps/files/?dir=/&fileid=982)
+ * @param string $route the route the user is currently at, e.g. files.view.index
+ * @param array $routeParameters the parameters of the route the user is currently at, e.g. [fileId = 982, dir = "/"]
*
* @return int